@@ -4,7 +4,8 @@
 #    This file is part of Data::FormValidator.
 #
 #    Author: Francis J. Lacoste
-#    Maintainer: Mark Stosberg <mark@stosberg.com>
+#    Previous Maintainer: Mark Stosberg <mark@stosberg.com>
+#    Maintainer: David Farrell <dfarrell@cpan.org>
 #
 #    Copyright (C) 1999 Francis J. Lacoste, iNsu Innovations
 #    Parts Copyright 1996-1999 by Michael J. Heins
@@ -25,13 +26,12 @@ package Data::FormValidator;
 use Exporter 'import';
 use 5.008;
 
-use Perl6::Junction qw(any none);
 use Data::FormValidator::Results;
 *_arrayify = \&Data::FormValidator::Results::_arrayify;
 use Data::FormValidator::Filters ':filters';
 use Data::FormValidator::Constraints qw(:validators :matchers);
 
-our $VERSION = '4.81';
+our $VERSION = '4.83';
 
 our %EXPORT_TAGS = (
     filters => [qw/
@@ -867,13 +867,13 @@ either use a named constraint, or use the hash ref method of defining a
 constraint and include a C<name> key with a value set to the name of your
 constraint.  Here's an example:
 
- my_zipcode_field => [
-     'zip',
-     {
-       constraint =>  '/^406/',
-       name        =>  'starts_with_406',
-     }
- ],
+  my_zipcode_field => [
+      'zip',
+      {
+        constraint_method =>  '/^406/',
+        name              =>  'starts_with_406',
+      }
+  ],
 
 You can use an array reference with a single constraint in it if you just want
 to have the name of your failed constraint returned in the above fashion.
@@ -944,7 +944,7 @@ sub _check_profile_syntax {
         # If any of the keys in the profile are not listed as
         # valid keys here, we die with an error
         for my $key (keys %$profile) {
-            push @invalid, $key unless ($key eq any(@valid_profile_keys));
+            push @invalid, $key unless grep $key eq $_, @valid_profile_keys;
         }
 
         local $" = ', ';
@@ -965,11 +965,11 @@ sub _check_profile_syntax {
         # Could be improved by also naming the associated key for the bad value.
         for my $key (grep { $profile->{$_} } qw/constraint_methods constraint_method_regexp_map/) {
             for my $val (map { _arrayify($_) } values %{ $profile->{$key} }) {
-                if ((ref $val eq 'HASH') and ref $val->{constraint_method} eq none('CODE','Regexp'))  {
+                if (ref $val eq 'HASH' && !grep(ref $val->{constraint_method} eq $_, 'CODE','Regexp'))  {
                     die "Value for constraint_method within hashref '$val->{constraint_method}' not a code reference or Regexp . Do you need func(), not 'func'?";
                 }
                 # Cases 1 through 4.
-                elsif (ref $val eq none('HASH','CODE','Regexp')) {
+                elsif (!grep(ref $val eq $_, 'HASH','CODE','Regexp')) {
                     die "Value for constraint_method '$val' not a code reference or Regexp . Do you need func(), not 'func'?";
                 }
                 # Case 5.
@@ -996,7 +996,7 @@ sub _check_profile_syntax {
 
         for my $href (@constraint_hashrefs) {
             for my $key (keys %$href) {
-                push @invalid, $key unless ($key eq any(@valid_constraint_hash_keys));
+                push @invalid, $key unless grep $key eq $_, @valid_constraint_hash_keys;
             }
         }
 
@@ -1019,7 +1019,7 @@ sub _check_profile_syntax {
         /);
         if (ref $profile->{msgs} eq 'HASH') {
             for my $key (keys %{ $profile->{msgs} }) {
-                push @invalid, $key unless ($key eq any(@valid_msgs_hash_keys));
+                push @invalid, $key unless grep $key eq $_, @valid_msgs_hash_keys;
             }
         }
         if (@invalid) {
@@ -1267,7 +1267,9 @@ Messages about DFV sent directly to the maintainer may be redirected here.
 
 =head1 AUTHOR
 
-Parts Copyright 2001-2006 by Mark Stosberg <mark at summersault.com>, (Current Maintainer)
+Currently maintained by David Farrell <dfarrell@cpan.org>
+
+Parts Copyright 2001-2006 by Mark Stosberg <mark at summersault.com>, (previous maintainer)
 
 Copyright (c) 1999 Francis J. Lacoste and iNsu Innovations Inc.  All rights reserved.
 (Original Author)
