@@ -14,7 +14,6 @@
 use strict;
 
 package Data::FormValidator::Results;
-use Perl6::Junction 'any';
 use Carp;
 use Symbol;
 use Data::FormValidator::Filters ':filters';
@@ -852,8 +851,8 @@ sub _arrayify {
 
    # if it's a reference, return an array unless it points to an empty array. -mls
    if ( ref $val eq 'ARRAY' ) {
-       $^W = 0; # turn off warnings about undef
-       return ( any(@$val) ne undef ) ? @$val : ();
+       local $^W = 0; # turn off warnings about undef
+       return grep(defined, @$val) ? @$val : ();
    }
    # if it's a string, return an array unless the string is missing or empty. -mls
    else {
@@ -1071,7 +1070,8 @@ sub _get_input_as_hash {
                 @v = $data->upload($k) || $data->param($k);
             }
             else {
-                @v = $data->param($k);
+                # insecure
+                @v = $data->multi_param($k);
             }
 
             # we expect param to return an array if there are multiple values
